<?php

/**
 * Touch Menu
 *
 * @version 2.0
 * @author Creative Pulse
 * @copyright Creative Pulse 2013-2014
 * @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 * @link http://www.creativepulse.gr
 */


if (!class_exists('CpWidget_TouchMenu')) {

	class CpWidget_TouchMenu {

		public $menu_items = array();
		public $category_id = 0;
		public $load_css = true;
		public $load_jquery = false;
		public $offset_x = 0;
		public $offset_y = 0;
		public $css_class_header_selected = '';

		public function view_id($new = false) {
			static $num = -1;

			if ($new) {
				$num++;
			}

			return $num;
		}

		public function load_libraries($name) {
			static $libraries = array();
			$result = !isset($libraries[$name]);
			$libraries[$name] = true;
			return $result;
		}

		public function json_esc($input) {
			$result = '';
			if (!is_string($input)) {
				$input = (string) $input;
			}

			$conv = array("\x08" => '\\b', "\t" => '\\t', "\n" => '\\n', "\f" => '\\f', "\r" => '\\r', '"' => '\\"', "'" => "\\'", '\\' => '\\\\', '<' => '\\u003C', '>' => '\\u003E');

			for ($i = 0, $len = strlen($input); $i < $len; $i++) {
				if (isset($conv[$input[$i]])) {
					$result .= $conv[$input[$i]];
				}
				else if ($input[$i] < ' ') {
					$result .= sprintf('\\u%04x', ord($input[$i]));
				}
				else {
					$result .= $input[$i];
				}
			}

			return $result;
		}

		public function prepare(&$params) {
			$this->category_id = intval($params->get('source_category_id'));
			$this->compact_article_id = intval($params->get('source_compact_article_id'));
			$this->panel_align_normal = $params->get('panel_align_normal');
			$this->offset_x = intval($params->get('offset_x'));
			$this->offset_y = intval($params->get('offset_y'));
			$this->panel_align_compact = $params->get('panel_align_compact');
			$this->content_align = $params->get('content_align');
			$this->panel_timeout = intval($params->get('panel_timeout'));
			$this->ani_duration = intval($params->get('ani_duration'));
			$this->load_css = intval($params->get('load_css'));
			$this->load_jquery = intval($params->get('load_jquery'));
			$this->resize_event_name = trim($params->get('resize_event_name'));
			$this->selector_compact_panel = trim($params->get('selector_compact_panel'));
			$this->selector_compact_open = trim($params->get('selector_compact_open'));
			$this->selector_compact_close = trim($params->get('selector_compact_close'));
			$this->selector_main_wrapper = trim($params->get('selector_main_wrapper'));
			$this->selector_compact_body = trim($params->get('selector_compact_body'));
			$this->css_class_header_selected = trim($params->get('css_class_header_selected'));
			$this->css_class_compact_fog = trim($params->get('css_class_compact_fog'));
			$this->css_class_compact_section_header = trim($params->get('css_class_compact_section_header'));
			$this->css_class_compact_section_content = trim($params->get('css_class_compact_section_content'));

			if ($this->category_id == 0) {
				// category not set - silent abort
				return;
			}

			$db = JFactory::getDBO();

			if ($this->category_id > 0) {
				$db->setQuery(
"SELECT o.`title`, o.`introtext`, o.`fulltext`
FROM #__categories a, #__content o
WHERE a.`id` = {$this->category_id} AND a.`published` = 1 AND a.`id` = o.`catid` AND o.`state` = 1
ORDER BY o.`ordering`"
				);

				$this->menu_items = $db->loadObjectList();

				if (!is_array($this->menu_items)) {
					$this->menu_items = array();
				}
			}

			$this->compact_article_content = '';
			if ($this->compact_article_id > 0) {
				$db->setQuery("SELECT `introtext`, `fulltext` FROM #__content WHERE `id` = {$this->compact_article_id} AND `state` = 1");
				$rec = $db->loadObject();
				if ($rec === null) {
					$this->compact_article_id = 0;
				}
				else {
					$this->compact_article_content = $rec->introtext . $rec->fulltext;
				}
			}

			if ($this->content_align == 'rtl') {
				$this->menu_items = array_reverse($this->menu_items);
			}

			if ($this->load_libraries('*')) {
				$document = JFactory::getDocument();
				$document->addScript('modules/mod_touchmenu/js/touchmenu.js');
				$document->addScriptDeclaration('document.wdg_touchmenu_db = [];');

				if ($this->load_jquery) {
					$document->addScript('modules/mod_touchmenu/js/jquery-2.1.3.min.js');
				}
			}
		}
	}

}

?>