
/**
 * Touch Menu
 *
 * @version 2.0
 * @author Creative Pulse
 * @copyright Creative Pulse 2013-2014
 * @license http://www.gnu.org/licenses/gpl-2.0.html GNU/GPL
 * @link http://www.creativepulse.gr
 */


jQuery(document).ready(function () {
	for (var i_db = 0, len_db = document.wdg_touchmenu_db.length; i_db < len_db; i_db++) {

		new (function (params) {
			this.timer = 0;
			this.panel_align_normal = typeof params.panel_align_normal != "string" ? "top-center" : params.panel_align_normal;
			this.offset_x = typeof params.offset_x != "number" ? 0 : params.offset_x;
			this.offset_y = typeof params.offset_y != "number" ? 0 : params.offset_y;
			this.panel_align_compact = typeof params.panel_align_compact != "string" ? "left" : params.panel_align_compact;
			this.content_align = typeof params.content_align != "string" ? "ltr" : params.content_align;
			this.panel_timeout = typeof params.panel_timeout == "number" && params.panel_timeout > 0 ? params.panel_timeout : 1000;
			this.ani_duration = typeof params.ani_duration == "number" && params.ani_duration > 0 ? params.ani_duration : 200;
			this.resize_event_name = typeof params.resize_event_name == "string" && params.resize_event_name != "" ? params.resize_event_name : "framech_resize";
			this.selector_main_wrapper = typeof params.selector_main_wrapper == "string" && params.selector_main_wrapper != "" ? params.selector_main_wrapper : ".framech-main";
			this.selector_compact_panel = typeof params.selector_compact_panel == "string" && params.selector_compact_panel != "" ? params.selector_compact_panel : ".menu-compact-panel";
			this.selector_compact_open = typeof params.selector_compact_open == "string" && params.selector_compact_open != "" ? params.selector_compact_open : ".menu-compact-open";
			this.selector_compact_close = typeof params.selector_compact_close == "string" && params.selector_compact_close != "" ? params.selector_compact_close : ".menu-compact-close";
			this.selector_compact_body = typeof params.selector_compact_body == "string" && params.selector_compact_body != "" ? params.selector_compact_body : ".menu-compact-body";
			this.css_class_header_selected = typeof params.css_class_header_selected == "string" && params.css_class_header_selected != "" ? params.css_class_header_selected : "selected";
			this.css_class_compact_fog = typeof params.css_class_compact_fog == "string" && params.css_class_compact_fog != "" ? params.css_class_compact_fog : "menu-compact-fog";
			this.css_class_compact_section_header = typeof params.css_class_compact_section_header == "string" && params.css_class_compact_section_header != "" ? params.css_class_compact_section_header : "menu-compact-section-header";
			this.css_class_compact_section_content = typeof params.css_class_compact_section_content == "string" && params.css_class_compact_section_content != "" ? params.css_class_compact_section_content : "menu-compact-section-content";

			var _this = this, $ = window.jQuery, base_cid = ".wdg-touchmenu-" + params.view_id;
			this.current_idx = -1;
			this.panel_is_open = false;
			this.$body = $("body");
			this.$win = $(window);
			this.$compact_content = $(base_cid + "-compact-content");

			this.LAYOUT_NORMAL = 0;
			this.LAYOUT_COMPACT = 1;
			this.layout = -1;


			// normal layout

			var content_css = {
				position: "absolute",
				top: 0,
				left: 0
			};

			switch (typeof params.content_z_index) {
				case "number":
					content_css["zIndex"] = params.content_z_index;
					break;

				case "string":
					params.content_z_index = params.content_z_index.replace(/^\s+|\s+$/g, "");
					if (params.content_z_index != "" && params.content_z_index.match(/^[0-9]+$/)) {
						content_css["zIndex"] = parseInt(params.content_z_index, 10);
					}
					break;
			}

			this.items = [];
			for (var i = 0; ; i++) {
				var $header_obj = $(base_cid + "-header-" + i);
				if ($header_obj.length == 0) {
					break;
				}

				$header_obj
					.attr("data-idx", i)
					.mouseover(function () { _this.on_mouseover(parseInt(this.getAttribute("data-idx"))); })
					.mouseout(function () { _this.on_mouseout(parseInt(this.getAttribute("data-idx"))); })
					.click(function () { _this.on_hd_click(parseInt(this.getAttribute("data-idx"))); });

				var $content_obj = $(base_cid + "-content-" + i)
					.css(content_css)
					.attr("data-idx", i)
					.mouseover(function () { _this.on_mouseover(parseInt(this.getAttribute("data-idx"))); })
					.mouseout(function () { _this.on_mouseout(parseInt(this.getAttribute("data-idx"))); });

				this.items.push({$normal_header: $header_obj, $normal_content: $content_obj});
			}

			this.on_mouseover = function (idx) {
				if (this.timer > 0) {
					clearTimeout(this.timer);
					this.timer = 0;
				}

				if (idx == this.current_idx) {
					return;
				}

				var was_open = false;

				if (idx != this.current_idx && this.current_idx > -1) {
					this.items[this.current_idx].$normal_header.removeClass(this.css_class_header_selected);
					if (this.panel_is_open) {
						was_open = true;
						this.panel_close(false);
					}
				}

				this.current_idx = idx;
				this.items[this.current_idx].$normal_header.addClass(this.css_class_header_selected);
				if (was_open) {
					this.panel_open(false);
				}
			}

			this.on_mouseout = function (idx) {
				if (idx != this.current_idx) {
					return;
				}

				if (this.panel_is_open) {
					var _this = this;
					this.timer = setTimeout(function () { _this.do_close(); }, this.panel_timeout);
				}
				else {
					this.items[this.current_idx].$normal_header.removeClass(this.css_class_header_selected);
					this.current_idx = -1;
				}
			}

			this.do_close = function () {
				this.timer = 0;
				this.items[this.current_idx].$normal_header.removeClass(this.css_class_header_selected);
				this.panel_close(true);
				this.current_idx = -1;
			}

			this.on_hd_click = function (idx) {
				if (this.layout == this.LAYOUT_NORMAL) {
					if (this.current_idx == -1) {
						// case: no menu was previously selected
						this.current_idx = idx;
						this.items[this.current_idx].$normal_header.addClass(this.css_class_header_selected);
						this.panel_open(true);
					}
					else if (this.current_idx != idx) {
						// case: another item was previously open

						this.items[this.current_idx].$normal_header.removeClass(this.css_class_header_selected);
						this.panel_close(false);

						this.current_idx = idx;
						this.items[this.current_idx].$normal_header.addClass(this.css_class_header_selected);
						this.panel_open(false);
					}
					else if (this.panel_is_open) {
						// case: the same item was previously selected with the content panel open
						this.items[this.current_idx].$normal_header.removeClass(this.css_class_header_selected);
						this.panel_close(true);
						this.current_idx = -1;
					}
					else {
						// case: the same item was previously selected with the content panel closed
						this.panel_open(true);
					}
				}
				else if (this.layout == this.LAYOUT_COMPACT) {
					if (this.current_idx == -1) {
						// case: no menu was previously selected
						this.current_idx = idx;
						this.items[this.current_idx].$compact_header.addClass(this.css_class_header_selected);
						this.items[this.current_idx].$compact_content.slideDown(this.ani_duration);
					}
					else if (this.current_idx != idx) {
						// case: another item was previously open

						this.items[this.current_idx].$compact_header.removeClass(this.css_class_header_selected);
						this.items[this.current_idx].$compact_content.slideUp(this.ani_duration);

						this.current_idx = idx;
						this.items[this.current_idx].$compact_header.addClass(this.css_class_header_selected);
						this.items[this.current_idx].$compact_content.slideDown(this.ani_duration);
					}
					else {
						// case: the same item was previously selected
						this.items[this.current_idx].$compact_header.removeClass(this.css_class_header_selected);
						this.items[this.current_idx].$compact_content.slideUp(this.ani_duration);
						this.current_idx = -1;
					}
				}
			}


			// compact layout

			this.$menu_compact_panel = $(this.selector_compact_panel);
			this.$menu_compact_fog = $("<div/>").appendTo(this.$body).addClass(this.css_class_compact_fog);

			$(this.selector_compact_close).click(function () {
				_this.panel_close(true);
			});

			this.$menu_compact_open_btn = $(this.selector_compact_open)
			this.$menu_compact_open_btn.click(function () {
				if (_this.panel_is_open) {
					_this.panel_close(true);
				}
				else {
					_this.panel_open(true);
				}
			});

			this.$main_wrapper = $(this.selector_main_wrapper);

			this.menu_compact_set = false;
			this.set_up_menu_compact = function () {
				var $ = window.jQuery, $dst = $(this.selector_compact_body)

				if (this.$compact_content.length > 0) {
					this.$compact_content.appendTo($dst).show();
				}
				else {
					for (var i = 0, len = this.items.length; i < len; i++) {
						this.items[i].$compact_header = $("<div/>")
							.appendTo($dst)
							.addClass(this.css_class_compact_section_header)
							.html(this.items[i].$normal_header.html())
							.attr("data-idx", i)
							.click(function () { _this.on_hd_click(parseInt(this.getAttribute("data-idx"))); });

						this.items[i].$compact_content = $("<div/>")
							.appendTo($dst)
							.addClass(this.css_class_compact_section_content)
							.html(this.items[i].$normal_content.html());
					}
				}

				this.menu_compact_set = true;
			}


			this.panel_open = function (animate) {
				if (this.layout == this.LAYOUT_NORMAL) {
					var $header = this.items[this.current_idx].$normal_header;
					var $content = this.items[this.current_idx].$normal_content;
					var header_pos = $header.offset();
					var left = 0, top = 0;

					switch (this.panel_align_normal) {
						case "top-left":
							left = (header_pos.left + this.offset_x) + "px";
							top = (header_pos.top + $header.height() + this.offset_y) + "px";
							break;

						case "top-center":
							left = Math.round(header_pos.left + $header.outerWidth() / 2 - $content.outerWidth() / 2 + this.offset_x) + "px";
							top = (header_pos.top + $header.height() + this.offset_y) + "px";
							break;

						case "top-right":
							left = (header_pos.left + $header.outerWidth() - $content.outerWidth() + this.offset_x) + "px";
							top = (header_pos.top + $header.height() + this.offset_y) + "px";
							break;
					}

					$content.appendTo(this.$body).css({left: left, top: top});

					if (animate) {
						$content.fadeIn(this.ani_duration);
					}
					else {
						$content.show();
					}
				}
				else if (this.layout == this.LAYOUT_COMPACT) {
					var _this = this, win_w = this.$win.width(), win_h = this.$win.height();
					this.$main_wrapper.css({width: win_w, height: win_h, overflow: "hidden"});
					this.$menu_compact_fog.appendTo(this.$body).css({width: win_w, height: win_h}).fadeIn(this.ani_duration).click(function () { _this.panel_close(true); });
					this.$menu_compact_panel.appendTo(this.$body).outerHeight(win_h).css({width: "auto", maxWidth: win_w * 0.8, overflow: "auto"});

					var start_x, end_x, w = this.$menu_compact_panel.outerWidth();
					if (this.panel_align_compact == "right") {
						start_x = win_w;
						end_x = win_w - w;
					}
					else {
						start_x = -w;
						end_x = 0;
					}

					if (animate) {
						this.$menu_compact_panel.css({left: start_x}).show().animate({left: end_x}, this.ani_duration);
					}
					else {
						this.$menu_compact_panel.css({left: end_x}).show();
					}

				}

				this.panel_is_open = true;
			}

			this.panel_close = function (animate) {
				if (this.layout == this.LAYOUT_NORMAL) {
					if (animate) {
						this.items[this.current_idx].$normal_content.fadeOut(this.ani_duration);
					}
					else {
						this.items[this.current_idx].$normal_content.hide();
					}
				}
				else if (this.layout == this.LAYOUT_COMPACT) {
					if (this.current_idx > -1) {
						this.items[this.current_idx].$compact_header.removeClass(this.css_class_header_selected);
						this.items[this.current_idx].$compact_content.hide();
						this.current_idx = -1;
					}

					this.$main_wrapper.css({width: "auto", height: "auto"});

					if (animate) {
						var x = this.panel_align_compact == "right" ? this.$win.width() : -this.$menu_compact_panel.outerWidth();
						this.$menu_compact_panel.animate({left: x}, this.ani_duration).fadeOut(this.ani_duration);
						this.$menu_compact_fog.fadeOut(this.ani_duration);
					}
					else {
						this.$menu_compact_panel.hide();
						this.$menu_compact_fog.hide();
					}
				}

				this.panel_is_open = false;
			}


			this.on_resize = function (layout_changed) {
				if (this.panel_is_open) {
					this.panel_close(false);
				}

				if (layout_changed) {
					var new_layout = this.$menu_compact_open_btn.is(":visible") ? this.LAYOUT_COMPACT : this.LAYOUT_NORMAL;
					if (this.layout != new_layout) {
						// change layout

						// finalize old layout
						if (this.layout == this.LAYOUT_NORMAL && this.current_idx > -1) {
							this.items[this.current_idx].$normal_header.removeClass(this.css_class_header_selected);
							this.current_idx = -1;
						}

						// initialize new layout
						this.layout = new_layout;
						if (this.layout == this.LAYOUT_COMPACT && !this.menu_compact_set) {
							this.set_up_menu_compact();
						}
					}
				}
			}

			$(window).resize(function () {
				_this.on_resize(false);
			});

			this.$body.on(this.resize_event_name, function (event, new_class) {
				_this.on_resize(true);
			});

			// initialize system size
			this.on_resize(true);

		})(document.wdg_touchmenu_db[i_db]);

	}
});
